@@ -87,8 +87,6 @@ explicit zz_pX(zz_p a) { *this = a; }
 
 zz_pX(INIT_SIZE_TYPE, long n) { rep.SetMaxLength(n); }
 
-zz_pX(const zz_pX& a) : rep(a.rep) { }
-// initial value is a
 
 inline zz_pX(long i, zz_p c);
 inline zz_pX(long i, long c);
@@ -97,13 +95,12 @@ inline zz_pX(INIT_MONO_TYPE, long i, zz_p c);
 inline zz_pX(INIT_MONO_TYPE, long i, long c);
 inline zz_pX(INIT_MONO_TYPE, long i);
 
-zz_pX& operator=(const zz_pX& a) 
-   { rep = a.rep; return *this; }
 
 inline zz_pX& operator=(long a);
 inline zz_pX& operator=(zz_p a);
 
-~zz_pX() { }
+// default copy constructor and assignment
+// default destructor
 
 void normalize();
 // strip leading zeros
@@ -140,6 +137,9 @@ zz_pX(zz_pX& x, INIT_TRANS_TYPE) : rep(x.rep, INIT_TRANS) { }
 };
 
 
+NTL_DECLARE_RELOCATABLE((zz_pX*))
+
+
 
 
 /********************************************************************
@@ -764,7 +764,6 @@ private:
 public:
 
    zz_pXMatrix() { }
-   ~zz_pXMatrix() { }
 
    void operator=(const zz_pXMatrix&);
    zz_pX& operator() (long i, long j) { return elts[i][j]; }
@@ -845,7 +844,6 @@ long InvModStatus(zz_pX& x, const zz_pX& a, const zz_pX& f);
 class zz_pXModulus {
 public:
    zz_pXModulus() : UseFFT(0), n(-1)  { }
-   ~zz_pXModulus() { }
 
    zz_pX f;   // the modulus
    long UseFFT;// flag indicating whether FFT should be used.
@@ -867,6 +865,9 @@ public:
 };
 
 
+NTL_DECLARE_RELOCATABLE((zz_pXModulus*))
+
+
 inline long deg(const zz_pXModulus& F) { return F.n; }
 
 void build(zz_pXModulus& F, const zz_pX& f);
@@ -965,7 +966,6 @@ public:
    zz_pXMultiplier() : UseFFT(0)  { }
    zz_pXMultiplier(const zz_pX& b, const zz_pXModulus& F);
 
-   ~zz_pXMultiplier() { }
 
    zz_pX b;   
    long UseFFT;
